' Connections (for L293D DIP):
' --------------------------------------
' P16 -> L293D.1 and L293D.9
' P17 -> L293D.2, L293D.3   -> Phase A 
' P18 -> L293D.7, L293D.6   -> Phase ~A
' P19 -> L293D.10, L293D.11 -> Phase B
' P20 -> L293D.15, L293D.14 -> Phase ~B


CON

  _CLKMODE      = XTAL1 + PLL16X
  _XINFREQ      = 5_000_000

  EN2           = 0
  M1            = EN2 + 1                                ' motor connections
  M4            = EN2 + 4
  EN            = 16                                     ' L293 enable inputs (both)
  N1            = EN + 1                                ' motor connections
  N4            = EN + 4                                ' -- (contiguous)

  STEPS_PER_REV = 400                                    ' steps per revolution
  MIN_STEP_MS   = 5                                   ' minimum step time


VAR

  long  idx


OBJ

  motor : "stepper"
  motor2: "steppers"


PUB main

  if motor.start(EN, MIN_STEP_MS) AND motor2.start(EN2, MIN_STEP_MS)
    motor.enable(true)                                  ' enable driver
    motor.setRun(true)                                  ' start the motor
    motor.stepRun
    motor2.enable(true)
    motor2.setRun(true)
    motor2.stepRun                                       ' set to step mode

    repeat idx from 1 to 1  
      motor.setSteps(STEPS_PER_REV)                     ' one revolution forward
      repeat until (motor.getSteps == 0)
      pause(200)
      motor.setSteps(-STEPS_PER_REV)                    ' one revolution reverse
      repeat until (motor.getSteps == 0)  
      pause(200)

    repeat idx from 1 to 1
      motor2.setSteps(STEPS_PER_REV)                     ' one revolution forward
      repeat until (motor2.getSteps == 0)
      pause(200)
      motor2.setSteps(-STEPS_PER_REV)                    ' one revolution reverse
      repeat until (motor2.getSteps == 0)  
      pause(200)

    motor.setStepTmr(500 / STEPS_PER_REV)
    motor2.setStepTmr(500 / STEPS_PER_REV)               ' set to 1/2 sec per revolution
    'motor.freeRun                                       ' free run mode when enabled

    motor.setRun(false)
    motor2.setRun(false)                                ' stop motor 
    motor.setDir(motor#RUN_FWD)
    motor2.setDir(motor#RUN_FWD)                         ' set direction to forward
    motor.setRun(true)
    motor2.setRun(true)                                ' stop motor                          ' set direction to forward                                  ' start motor      
    pause(5_000)                                        ' run for 5 seconds
    
    motor.setRun(false)
    motor.setDir(motor#RUN_REV)
    motor.setRun(true)
    motor2.setRun(false)
    motor2.setDir(motor#RUN_REV)
    motor2.setRun(true)
    pause(5_000)
    
    motor.setRun(false)
    motor2.setRun(false) 
    motor.stop
    motor2.stop                                  ' unload object
    

PRI pause(ms) | c

  c := cnt                                              ' sync with system counter
  repeat until (ms-- == 0)                              ' repeat while time left
    waitcnt(c += clkfreq / 1000)                        ' wait 1 ms